@@ -6,6 +6,7 @@ from sdccli.printer import print_item, print_list
 def formats():
     return {
         "scanningImage": _print_image,
+        "scanningImageAdded": _print_image_added,
         "scanningImageList": _print_images,
         "scanningQueryImage": _print_query,
         "scanningVulnImage": _print_vuln,
@@ -13,23 +14,27 @@ def formats():
     }
 
 
-def _print_image(images):
+def _print_image_added(images):
     for image in images:
-        image["fulltag"] = [d["fulltag"] for d in image['image_detail']]
-        if 'image_content' in image and image['image_content']:
-            image_content = image['image_content']
-            if 'metadata' in image_content and image_content['metadata']:
-                image_content_metadata = image_content['metadata']
-                image['dockerfile_mode'] = str(image_content_metadata['dockerfile_mode'])
-                image['distro'] = str(image_content_metadata['distro'])
-                image['distro_version'] = str(image_content_metadata['distro_version'])
-                image['size'] = str(image_content_metadata['image_size'])
-                image['arch'] = str(image_content_metadata['arch'])
-                image['layer_count'] = str(image_content_metadata['layer_count'])
+        _print_image(image)
 
-        keys = ["imageDigest", "imageId", "parentDigest", "analysis_status", "image_type", "fulltag",
-                "dockerfile_mode", "distro", "distro_version", "size", "arch", "layer_count", "annotations"]
-        print_item(image, keys)
+
+def _print_image(image):
+    image["fulltag"] = [d["fulltag"] for d in image['image_detail']]
+    if 'image_content' in image and image['image_content']:
+        image_content = image['image_content']
+        if 'metadata' in image_content and image_content['metadata']:
+            image_content_metadata = image_content['metadata']
+            image['dockerfile_mode'] = str(image_content_metadata['dockerfile_mode'])
+            image['distro'] = str(image_content_metadata['distro'])
+            image['distro_version'] = str(image_content_metadata['distro_version'])
+            image['size'] = str(image_content_metadata['image_size'])
+            image['arch'] = str(image_content_metadata['arch'])
+            image['layer_count'] = str(image_content_metadata['layer_count'])
+
+    keys = ["imageDigest", "imageId", "parentDigest", "analysis_status", "image_type", "fulltag",
+            "dockerfile_mode", "distro", "distro_version", "size", "arch", "layer_count", "annotations"]
+    print_item(image, keys)
 
 
 def _print_query(res):
@@ -120,4 +125,4 @@ def _print_evaluation(res):
     if scan_info["stop_results"]:
         print("Stop results:")
         for stop_result in scan_info["stop_results"]:
-            print(f"  x {stop_result}")
\ No newline at end of file
+            print(f"  x {stop_result}")
