@@ -16,9 +16,9 @@ from sdccli.time import duration_to_seconds
 
 _item_keys_v1 = ["id", "name", "description", "falcoConfiguration", "actions", "scope", "notificationChannelIds"]
 _list_keys_v1 = ["id", "name", "severity", "isBuiltin", "notificationChannelIds"]
-_item_keys = ["id", "name", "description", "severity", "enabled", "scope", "ruleNames", "actions",
+_item_keys = ["id", "name", "description", "type", "severity", "enabled", "scope", "ruleNames", "actions",
               "notificationChannelIds"]
-_list_keys = ["id", "name", "severity", "enabled"]
+_list_keys = ["id", "name", "type", "severity", "enabled"]
 
 
 @click.group(name='policy', short_help='Sysdig Secure policy operations')
@@ -43,8 +43,9 @@ policy.add_command(falco_macro)
               help="How severe is this policy when violated. Range from 0 to 7 included.")
 @click.option('--notenabled', is_flag=True, help=" If the policy should not be considered")
 @click.option('--notification', nargs=1, multiple=True, help="Notification channel id to subscribe to the policy.")
+@click.option('--type', nargs=1, default="falco", type=click.STRING, help="Policy type, it can be one of: falco, list_matching, k8s_audit, aws_cloudvision")
 @click.pass_obj
-def add(cnf, name, description, rule, action, scope, severity, notenabled, notification):
+def add(cnf, name, description, rule, action, scope, severity, notenabled, notification, type):
     """
     NAME: the name of the new policy.
 
@@ -54,6 +55,7 @@ def add(cnf, name, description, rule, action, scope, severity, notenabled, notif
         print("Error: Sysdig Secure doesn't support policy API v2, use add-json instead")
         sys.exit(1)
 
+
     ok, res = cnf.sdsecure.add_policy(
         name, description,
         rule_names=rule,
@@ -61,7 +63,8 @@ def add(cnf, name, description, rule, action, scope, severity, notenabled, notif
         scope=scope,
         severity=severity,
         enabled=not notenabled,
-        notification_channels=notification)
+        notification_channels=notification,
+        type=type)
 
     if cnf.json:
         print(json.dumps(res, indent=4))
